@@ -1,6 +1,6 @@
 package Reddit::Client;
 
-our $VERSION = '1.0961'; 
+our $VERSION = '1.0965'; 
 $VERSION = eval $VERSION;
 
 use strict;
@@ -144,7 +144,7 @@ $API[API_DELETEMULTI   ] = ['DELETE','/api/multi/user/%s/m/%s'];
 $API[API_EDITMULTI     ] = ['PUT',  '/api/multi/user/%s/m/%s' ];
 $API[API_SUBREDDIT_INFO] = ['GET',  '/r/%s/about'             ];
 $API[API_SEARCH        ] = ['GET',  '/r/%s/search'            ];
-$API[API_MODQ          ] = ['GET',  '/r/%s/about/modqueue'    ];
+$API[API_MODQ          ] = ['GET',  '/r/%s/about/%s'          ];
 #===============================================================================
 # Package routines
 #===============================================================================
@@ -567,10 +567,11 @@ sub get_modlinks {
 
 	my $query = $self->set_listing_defaults(%param);
 	my $sub   = $param{sub} || $param{subreddit} || 'mod';
+	my $mode  = $param{mode} || 'modqueue';
 
     	my $result = $self->api_json_request(
 		api  => API_MODQ, 
-		args => [$sub],
+		args => [$sub, $mode],
 		data => $query,
 	);
 
